L'héritage en Java
==================
![category](java)
![tag](java)

L'héritage un moyen simple d'écrire un minimum de code.
Le principe est d'indiquer qu'une classe est issue d'une autre
type de classe.

Un exemple simple: nous avons une classe "Être vivant" qui a une propriété qui 
est *âge*. Il existe une autre classe nommé "mammifère" qui hérite de la classe
"Être vivant" et donc de la propriété "âge".

Exemple
-------

.. aafig::
    :textual:

    /-------------------------\        /------------------------\  
    |         'Task'          |        |       'RDV'            | 
    +-------------------------+        +------------------------+ 
    | '# label : string'      |        | '# date : string'      |  
    | '# state : boolean'     +<-------+------------------------+  
    +-------------------------+        | '+ isLate(): boolean'  |
    | '+ done()'              |        | '+ toString(): string' |
    | '+ isDone() : boolean'  |        \------------------------/       
    | '+ toString() : string' |               
    \-------------+-----------/               
                  ^
                  |
    /-------------+----------------------------\
    |                'SimpleTask'              |
    +------------------------------------------+
    |                                          |
    +------------------------------------------+
    | '+ toString() : string'                  |
    \------------------------------------------/


le fichier Task.java

```java
/**
 * Classe Task
 * @author Fred
 *
 */


public abstract class Task {

    private String label;
    private Boolean state;

    protected Boolean getState() {
        return this.state;
    }
    
    protected void setState(Boolean state) {
        this.state = state;
    }

    protected String getLabel() {
        return this.label;
    }
    
    protected void setLabel(String label) {
        this.label = label;
    }


    /**
     * Constructer
     *
     * @param label desc task
     * @param state state of task
     */
    public Task(String label, Boolean state) {
        this.setLabel(label);
        this.setState(state);
    }

    /**
     * print task
     *
     * @return label and state
     */
    public abstract String toString();

    /**
     * state to true
     */
    public void done() {
        this.setState(true);
    }

    /**
     * get state of Task
     * @return state of Task: true or false
     */
    public Boolean isDone() {
        return this.getState();
    }
}
```

le fichier SimpleTask.java

```java
/**
 * Classe SimpleTask
 * @author Fred
 *
 */


public class SimpleTask extends Task {

    /**
     * Constructer
     *
     * @param label desc task
     * @param state state of task
     */
    public SimpleTask(String label, Boolean state) {
        super(label, state);
    }

    /**
     * print task
     *
     * @return label and state
     */
    public String toString() {
        if (this.isDone()) {
            return "task: " + this.getLabel() + " Ok";
        } else {
            return "task: " + this.getLabel() + " Ko";
        }
    };

}
```

le fichier RDV.java

```java
/**
 * Classe RDV
 * @author Fred
 *
 */

public class RDV extends Task {

    private String date;

    public String getDate() {
        return this.date;
    }
    
    public void setDate(String date) {
        this.date = date;
    }
    /**
     * Constructer
     *
     * @param label desc task
     * @param state state of task
     */
    public RDV(String date, String label, Boolean state) {
        super(label, state);
        this.setDate(date);
    }

    /**
     * print task
     *
     * @return label and state
     */
    public String toString() {
        if (this.isDone()) {
            return "task for " + this.getDate() +" : " + this.getLabel() + " Ok";
        } else {
            return "task for " + this.getDate() + " : " + this.getLabel() + " Ko";
        }
    };

}
```

et un bout de code pour tester tout cela

fichier TodoList.java

```java
/**
 * Prg Task Management
 */

/**
 * Classe de demarrage
 * @author Fred
 *
 */

public class TodoList {
    /**
     * Prog principal
     * @param args no desc
     *
     */
    public static void main(String[] args) {
        Task t1 = new SimpleTask("Test", false);
        System.out.println(t1);
        Task t2 = new RDV("23/12/2015", "Test", false);
        System.out.println(t2);
    }

}
```

```bash
javac TodoList.java
java TodoList
```

Il faut noter

#. l'utilisation du terme abstract et extends
#. l'encapsulation des attributs label et state
#. la protection via *protected* des set et get de la classe Task
